For developers
==============

..  toctree::

    codebase
    coding_standards
    documentation
    tests
    ajv

Development notes
-----------------

..  toctree::
    :maxdepth: 1

    timing
    profiling
    memory
    class_attributes
    slots
